metadata(version="0.3.0")

# Originally written by Paul Sokolovsky.

require("os")
require("ffilib")

module("select.py")
